@@ -5,7 +5,7 @@
  *      Author: mkooyman
  *
  *
- * Copyright (C) 2009--2014 Various members of the GenABEL team. See
+ * Copyright (C) 2009--2015 Various members of the GenABEL team. See
  * the SVN commit logs for more details.
  *
  * This program is free software; you can redistribute it and/or
@@ -116,16 +116,16 @@ coxph_data::coxph_data(phedata &phed, gendata &gend, const int snpnum)
         exit(1);
     }
 
-    X.reinit(nids, ncov);
+    X.reinit(nids, (ncov + 1));
     stime.reinit(nids, 1);
     sstat.reinit(nids, 1);
     weights.reinit(nids, 1);
     offset.reinit(nids, 1);
     strata.reinit(nids, 1);
     order.reinit(nids, 1);
+
     for (int i = 0; i < nids; i++)
     {
-        //          X.put(1.,i,0);
         stime[i] = (phed.Y).get(i, 0);
         sstat[i] = static_cast<int>((phed.Y).get(i, 1));
         if (sstat[i] != 1 && sstat[i] != 0)
@@ -137,12 +137,21 @@ coxph_data::coxph_data(phedata &phed, gendata &gend, const int snpnum)
         }
     }
 
-    for (int j = 0; j < phed.ncov; j++)
+    // Add a column with a constant (=1) to the X matrix (the mean)
+    for (int i = 0; i < nids; i++)
+    {
+        X.put(1., i, 0);
+    }
+
+    for (int j = 1; j <= phed.ncov; j++)
     {
         for (int i = 0; i < nids; i++)
-            X.put((phed.X).get(i, j), i, j);
+        {
+            X.put((phed.X).get(i, j - 1), i, j);
+        }
     }
 
+
     if (snpnum > 0)
     {
         for (int j = 0; j < ngpreds; j++)
@@ -246,7 +255,7 @@ void coxph_data::update_snp(gendata *gend, const int snpnum) {
         gend->get_var(snpnum * ngpreds + j, snpdata);
 
         for (int i = 0; i < nids; i++) {
-            X.put(snpdata[i], (ncov - j - 1), order[i]);
+            X.put(snpdata[i], (ncov - j), order[i]);
             if (std::isnan(snpdata[i])) {
                 masked_data[order[i]] = 1;
                 // snp not masked
@@ -398,8 +407,6 @@ void coxph_reg::estimate(coxph_data &cdatain, const int verbose,
         (cdata.offset).column_mean(0);
     mematrix<double> means(X.nrow, 1);
 
-    int maxiterinput = maxiter;
-
     for (int i = 0; i < X.nrow; i++)
     {
         beta[i] = 0.;
@@ -418,6 +425,10 @@ void coxph_reg::estimate(coxph_data &cdatain, const int verbose,
     // R's coxph()
     double sctest = 1.0;
 
+    // Set the maximum number of iterations that coxfit2() will run to
+    // the default value from the class definition.
+    int maxiterinput = maxiter;
+
     // When using Eigen coxfit2 needs to be called in a slightly
     // different way (i.e. the .data()-part needs to be added).
 #if EIGEN
@@ -438,22 +449,50 @@ void coxph_reg::estimate(coxph_data &cdatain, const int verbose,
 
     niter = maxiter;
 
+
     // Check the results of the Cox fit; mirrored from the same checks
-    // in coxph_fit.S from the R survival package
+    // in coxph.fit.S and coxph.R from the R survival package.
 
-    bool setToZero = false;
+    bool setToNAN = false;
 
-    if (flag < X.nrow && maxiter > 0) {
-        cerr << "Warning for " << snpinfo.name[cursnp]
-             << ": X matrix deemed to be singular,"
-             << " setting beta and se to 'nan'\n";
-        setToZero = true;
+    // Based on coxph.fit.S lines with 'which.sing' and coxph.R line
+    // with if(any(is.NA(coefficients))). These lines set coefficients
+    // to NA if flag < nvar (with nvar = ncol(x)) and maxiter >
+    // 0. coxph.R then checks for any NAs in the coefficients and
+    // outputs the warning message if NAs were found.
+
+    if (flag < X.nrow)
+    {
+#if EIGEN
+        int which_sing = 0;
+        MatrixXd imateigen = imat.data;
+        VectorXd imatdiag = imateigen.diagonal();
+
+        // Start at i=1 to exclude the beta coefficient for the
+        // (constant) mean from the check.
+        for (int i=1; i < imatdiag.size(); i++)
+        {
+            if (imatdiag[i] == 0)
+                {
+                    which_sing = i;
+                    setToNAN = true;
+                    std::cerr << "Warning for " << snpinfo.name[cursnp]
+                              << ": X matrix deemed to be singular (variable "
+                              << which_sing + 1 << ")" << std::endl;
+                }
+        }
+#else
+        std::cerr << "Warning for " << snpinfo.name[cursnp]
+                  << ": can't check for singular X matrix."
+                  << " Please compile ProbABEL with Eigen support to fix this."
+                  << std::endl;
+#endif
     }
 
     if (niter >= maxiterinput)
     {
         cerr << "Warning for " << snpinfo.name[cursnp]
-             << ": nr of iterations > MAXITER (" << maxiterinput << "): "
+             << ": nr of iterations >= MAXITER (" << maxiterinput << "): "
              << niter << endl;
     }
 
@@ -461,22 +500,35 @@ void coxph_reg::estimate(coxph_data &cdatain, const int verbose,
     {
         cerr << "Warning for " << snpinfo.name[cursnp]
              << ": Cox regression ran out of iterations and did not converge,"
-             << " setting beta and se to 'nan'\n";
-        setToZero = true;
+             << " setting beta and se to 'NaN'\n";
+        setToNAN = true;
     } else {
 #if EIGEN
         VectorXd ueigen = u.data;
         MatrixXd imateigen = imat.data;
         VectorXd infs = ueigen.transpose() * imateigen;
+        infs = infs.cwiseAbs();
         VectorXd betaeigen = beta.data;
-        if ( infs.norm() > eps ||
-            infs.norm() > sqrt(eps) * betaeigen.norm() )
-        {
+        bool problems = false;
+
+        assert(betaeigen.size() == infs.size());
+
+        // We check the beta's for all coefficients
+        // (incl. covariates), maybe stick to only checking the SNP
+        // coefficient?
+        for (int i = 0; i < infs.size(); i++) {
+            if (infs[i] > eps &&
+                infs[i] > sqrt(eps) * abs(betaeigen[i])) {
+                problems = true;
+            }
+        }
+
+        if (problems) {
             cerr << "Warning for " << snpinfo.name[cursnp]
                  << ": beta may be infinite,"
-                 << " setting beta and se to 'nan'\n";
+                 << " setting beta and se to 'NaN'\n";
 
-            setToZero = true;
+            setToNAN = true;
         }
 #else
         cerr << "Warning for " << snpinfo.name[cursnp]
@@ -488,7 +540,7 @@ void coxph_reg::estimate(coxph_data &cdatain, const int verbose,
 
     for (int i = 0; i < X.nrow; i++)
     {
-        if (setToZero)
+        if (setToNAN)
         {
             // Cox regression failed
             sebeta[i] = NAN;
