@@ -1,3 +1,26 @@
+/*
+ *
+ * Copyright (C) 2009--2014 Various members of the GenABEL team. See
+ * the SVN commit logs for more details.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA  02110-1301, USA.
+ *
+ */
+
+
 #include "reg1.h"
 
 
@@ -696,7 +719,8 @@ void logistic_reg::estimate(regdata& rdatain, int verbose, int maxiter,
             double emu = eMu.get(i, 0);
             double value = emu;
             double zval;
-            value = exp(value) / (1. + exp(value));
+            double expval = exp(value);
+            value = expval / (1. + expval);
             residuals[i] = (rdata.Y).get(i, 0) - value;
             eMu.put(value, i, 0);
             W.put(value * (1. - value), i, 0);
@@ -755,11 +779,13 @@ void logistic_reg::estimate(regdata& rdatain, int verbose, int maxiter,
             beta.print();
         }
         // std::cout << "beta:\n"; beta.print();
-        // compute likelihood
+
+        // Compute the likelihood.
         prevlik = loglik;
-        loglik = 0.;
-        for (int i = 0; i < eMu.nrow; i++)
+        loglik = 0;
+        for (int i = 0; i < eMu.nrow; i++) {
             loglik += rdata.Y[i] * eMu_us[i] - log(1. + exp(eMu_us[i]));
+        }
 
         delta = fabs(1. - (prevlik / loglik));
         niter++;
